"""This is the description of this module. It is intended for test, nothing else"""

import tkinter as tk

PATH = "open_the_door"

class Mega(tk.Frame):
    pass
    
    def well(self):
        pass


class Jack:
    """Jack class"""
    def __init__(self):
        """jack initialisation
        [parameters]
        - a: this is a rich parameter.
        Use it mainly for this.
        You can still do this too.
        
        - b: y
        [exceptions]
        - errorX: the X error
        - errorY: the Y error
        """
        pass
        
    JACK_CONSTANT = "jackkk_constant"
    
    @property
    def wesh(self):
        """This is a description.
        Jumping into new line here."""
        return None
        
    @wesh.setter
    def wesh(self, val):
        pass
    
    def ok(self):
        """jack ok"""
        pass
        
        
class _Jack:
    """_Jack doc"""
    def __init__(self):
        """_Jack ok"""
        pass
        
    def ok(self):
        """_Jack ok"""
        pass
        
        
def loui(age=None):
    """loui function"""
    pass
    
    
    
